PRACE RAMP ASTRO BENCHMARK
==========================

Authors
-------
- Bertrand Rigaud - <bertrand.rigaud@cc.in2p3.fr>
- Alexandre Boucaud - <aboucaud@lal.in2p3.fr>


Description
-----------

This benchmark is based on a toy [deep learning challenge](https://github.com/ramp-kits/astrophd_tutorial) organised by [Alexandre Boucaud](https://github.com/aboucaud) and [Marc Huertas-Company](http://www.iufrance.fr/les-membres-de-liuf/membre/1533-marc-huertas-company.html) using the [RAMP platform](https://www.ramp.studio/) for a PhD school in April 2018.

The challenge uses 20 000 images (128x128 pixels, 32 bits) made of two galaxies overlapping (1st image), referred to as _blended_. These galaxies have been extracted from real images from the _Hubble Space Telescope_ and combined manually to create the blends.  
The goal of the challenge is to train a model that can automatically detect the contiguous region (_mask_) where the 3-sigma light of the two galaxies overlap (2nd image).  
The model predicts a probability for each pixel to belong to such region, and the probabilistic image (3rd image) is then thresholded to obtain an actual prediction (4th image).

<img src="galaxies.png" width="600px" />

The model implemented here for the PRACE benchmark test is a [UNet](https://arxiv.org/abs/1505.04597), quite famous in image segmentation.
The whole benchmark is written using the [Keras](https://keras.io) library with a [Tensorflow](https://www.tensorflow.org) backend.
The dataset (2 Gb) is divided into 12 000 images for the training, 4 000 for the validation (during training) and 4 000 images for the final evaluation of the model.


Requirements
------------
Singularity (2.4.2):  
http://singularity.lbl.gov/docs-installation

If you do not plan to use Singularity:  
Python version: 3.6+
```bash
pip install -r requirements_gpu.txt
```

Instructions
------------

1. Create a Singularity image from image_definitions/prace-ramp-astro-benchmark.def  
  ```bash
  sudo singularity build image_definitions/prace-ramp-astro-benchmark.simg image_definitions/prace-ramp-astro-benchmark.def
  ```

2. Set the environment variables (modify the `config.sh`)  
  ```bash
  cp config_template.sh config.sh
  vi config.sh
  source config.sh
  ```

3. Download the data
  ```bash
  python download_data.py $ASTRO_DATASET_PATH
  ```

3. Send app to gpu batch farm:  
```bash
qsub -l GPU=$ASTRO_NUM_GPUS -q $ASTRO_FARM_QUEUE_HOST -pe multicores_gpu $ASTRO_NUM_CORES -o $ASTRO_OUTPUT_PATH -e $ASTRO_OUTPUT_PATH -V  $ASTRO_BASE_PATH/batch_launcher.sh
```

Outputs
-------

This workflow produces:  
- batch files (output, error)
- results (results.csv)
- neural network model (unet_weights-best.h5)
- train history plot (train_history.png)

License
-------
This work is released under a BSD-3 license, see [LICENSE](LICENSE) file for more details.
