# Author: Alexandre Boucaud <aboucaud@lal.in2p3.fr>
# License: BSD 3 clause

from sklearn.utils import Bunch


def init_model_params():
    params_model = Bunch()

    # image and class parameters
    params_model.img_rows = 128
    params_model.img_cols = 128
    params_model.img_channels = 1

    # architecture params
    params_model.output_channels = 1
    # percentage of weights not updated (0 = no dropout)
    params_model.dropout_rate = 0.2

    # optimizer parameters
    params_model.lr = 1e-4
    params_model.beta_1 = 0.9
    params_model.beta_2 = 0.999
    params_model.epsilon = 1e-08
    params_model.decay = 5e-05

    # loss parameters
    params_model.keras_loss = 'binary_crossentropy'

    # callbacks parameters
    params_model.early_stopping = False
    params_model.es_patience = 12
    params_model.es_min_delta = 0.001

    params_model.reduce_learning_rate = False
    params_model.lr_patience = 5
    params_model.lr_factor = 0.5
    params_model.lr_min_delta = 0.001
    params_model.lr_cooldown = 2

    return params_model
